==> kubernetes-model-apiextensions-6.3.1-sources.jar: io/fabric8/kubernetes/api/model/apiextensions/v1/CustomResourceSubresourcesFluentImpl.java <==
package io.fabric8.kubernetes.api.model.apiextensions.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class CustomResourceSubresourcesFluentImpl<A extends CustomResourceSubresourcesFluent<A>> extends BaseFluent<A> implements CustomResourceSubresourcesFluent<A>{
  public CustomResourceSubresourcesFluentImpl() {
  }
  public CustomResourceSubresourcesFluentImpl(CustomResourceSubresources instance) {
    this.withScale(instance.getScale()); 
    this.withStatus(instance.getStatus()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private CustomResourceSubresourceScaleBuilder scale;
  private CustomResourceSubresourceStatusBuilder status;
  private Map<String,Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildScale instead.
   * @return The buildable object.
   */
  @Deprecated
  public CustomResourceSubresourceScale getScale() {
    return this.scale!=null ?this.scale.build():null;
  }
  public CustomResourceSubresourceScale buildScale() {
    return this.scale!=null ?this.scale.build():null;
  }
  public A withScale(CustomResourceSubresourceScale scale) {
    _visitables.get("scale").remove(this.scale);
    if (scale!=null){ this.scale= new CustomResourceSubresourceScaleBuilder(scale); _visitables.get("scale").add(this.scale);} else { this.scale = null; _visitables.get("scale").remove(this.scale); } return (A) this;
  }
  public Boolean hasScale() {
    return this.scale != null;
  }
  public A withNewScale(String labelSelectorPath,String specReplicasPath,String statusReplicasPath) {
    return (A)withScale(new CustomResourceSubresourceScale(labelSelectorPath, specReplicasPath, statusReplicasPath));
  }
  public CustomResourceSubresourcesFluent.ScaleNested<A> withNewScale() {
    return new CustomResourceSubresourcesFluentImpl.ScaleNestedImpl();
  }
  public CustomResourceSubresourcesFluent.ScaleNested<A> withNewScaleLike(CustomResourceSubresourceScale item) {
    return new CustomResourceSubresourcesFluentImpl.ScaleNestedImpl(item);
  }
  public CustomResourceSubresourcesFluent.ScaleNested<A> editScale() {
    return withNewScaleLike(getScale());
  }
  public CustomResourceSubresourcesFluent.ScaleNested<A> editOrNewScale() {
    return withNewScaleLike(getScale() != null ? getScale(): new CustomResourceSubresourceScaleBuilder().build());
  }
  public CustomResourceSubresourcesFluent.ScaleNested<A> editOrNewScaleLike(CustomResourceSubresourceScale item) {
    return withNewScaleLike(getScale() != null ? getScale(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public CustomResourceSubresourceStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public CustomResourceSubresourceStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(CustomResourceSubresourceStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new CustomResourceSubresourceStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public CustomResourceSubresourcesFluent.StatusNested<A> withNewStatus() {
    return new CustomResourceSubresourcesFluentImpl.StatusNestedImpl();
  }
  public CustomResourceSubresourcesFluent.StatusNested<A> withNewStatusLike(CustomResourceSubresourceStatus item) {
    return new CustomResourceSubresourcesFluentImpl.StatusNestedImpl(item);
  }
  public CustomResourceSubresourcesFluent.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public CustomResourceSubresourcesFluent.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new CustomResourceSubresourceStatusBuilder().build());
  }
  public CustomResourceSubresourcesFluent.StatusNested<A> editOrNewStatusLike(CustomResourceSubresourceStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    CustomResourceSubresourcesFluentImpl that = (CustomResourceSubresourcesFluentImpl) o;
    if (scale != null ? !scale.equals(that.scale) :that.scale != null) return false;
    if (status != null ? !status.equals(that.status) :that.status != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(scale,  status,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (scale != null) { sb.append("scale:"); sb.append(scale + ","); }
    if (status != null) { sb.append("status:"); sb.append(status + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class ScaleNestedImpl<N> extends CustomResourceSubresourceScaleFluentImpl<CustomResourceSubresourcesFluent.ScaleNested<N>> implements CustomResourceSubresourcesFluent.ScaleNested<N>,Nested<N>{
    ScaleNestedImpl(CustomResourceSubresourceScale item) {
      this.builder = new CustomResourceSubresourceScaleBuilder(this, item);
    }
    ScaleNestedImpl() {
      this.builder = new CustomResourceSubresourceScaleBuilder(this);
    }
    CustomResourceSubresourceScaleBuilder builder;
    public N and() {
      return (N) CustomResourceSubresourcesFluentImpl.this.withScale(builder.build());
    }
    public N endScale() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends CustomResourceSubresourceStatusFluentImpl<CustomResourceSubresourcesFluent.StatusNested<N>> implements CustomResourceSubresourcesFluent.StatusNested<N>,Nested<N>{
    StatusNestedImpl(CustomResourceSubresourceStatus item) {
      this.builder = new CustomResourceSubresourceStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new CustomResourceSubresourceStatusBuilder(this);
    }
    CustomResourceSubresourceStatusBuilder builder;
    public N and() {
      return (N) CustomResourceSubresourcesFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}

==> kubernetes-model-apiextensions-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/apiextensions/v1/CustomResourceSubresourcesFluentImpl.java <==
package io.fabric8.kubernetes.api.model.apiextensions.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class CustomResourceSubresourcesFluentImpl<A extends CustomResourceSubresourcesFluent<A>> extends BaseFluent<A> implements CustomResourceSubresourcesFluent<A>{
  public CustomResourceSubresourcesFluentImpl() {
  }
  public CustomResourceSubresourcesFluentImpl(CustomResourceSubresources instance) {
    if (instance != null) {
      this.withScale(instance.getScale());
      this.withStatus(instance.getStatus());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private CustomResourceSubresourceScaleBuilder scale;
  private CustomResourceSubresourceStatusBuilder status;
  private Map<String,Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildScale instead.
   * @return The buildable object.
   */
  @Deprecated
  public CustomResourceSubresourceScale getScale() {
    return this.scale!=null ?this.scale.build():null;
  }
  public CustomResourceSubresourceScale buildScale() {
    return this.scale!=null ?this.scale.build():null;
  }
  public A withScale(CustomResourceSubresourceScale scale) {
    _visitables.get("scale").remove(this.scale);
    if (scale!=null){ this.scale= new CustomResourceSubresourceScaleBuilder(scale); _visitables.get("scale").add(this.scale);} else { this.scale = null; _visitables.get("scale").remove(this.scale); } return (A) this;
  }
  public Boolean hasScale() {
    return this.scale != null;
  }
  public A withNewScale(String labelSelectorPath,String specReplicasPath,String statusReplicasPath) {
    return (A)withScale(new CustomResourceSubresourceScale(labelSelectorPath, specReplicasPath, statusReplicasPath));
  }
  public CustomResourceSubresourcesFluentImpl.ScaleNested<A> withNewScale() {
    return new CustomResourceSubresourcesFluentImpl.ScaleNestedImpl();
  }
  public CustomResourceSubresourcesFluentImpl.ScaleNested<A> withNewScaleLike(CustomResourceSubresourceScale item) {
    return new CustomResourceSubresourcesFluentImpl.ScaleNestedImpl(item);
  }
  public CustomResourceSubresourcesFluentImpl.ScaleNested<A> editScale() {
    return withNewScaleLike(getScale());
  }
  public CustomResourceSubresourcesFluentImpl.ScaleNested<A> editOrNewScale() {
    return withNewScaleLike(getScale() != null ? getScale(): new CustomResourceSubresourceScaleBuilder().build());
  }
  public CustomResourceSubresourcesFluentImpl.ScaleNested<A> editOrNewScaleLike(CustomResourceSubresourceScale item) {
    return withNewScaleLike(getScale() != null ? getScale(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public CustomResourceSubresourceStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public CustomResourceSubresourceStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(CustomResourceSubresourceStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new CustomResourceSubresourceStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public CustomResourceSubresourcesFluentImpl.StatusNested<A> withNewStatus() {
    return new CustomResourceSubresourcesFluentImpl.StatusNestedImpl();
  }
  public CustomResourceSubresourcesFluentImpl.StatusNested<A> withNewStatusLike(CustomResourceSubresourceStatus item) {
    return new CustomResourceSubresourcesFluentImpl.StatusNestedImpl(item);
  }
  public CustomResourceSubresourcesFluentImpl.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public CustomResourceSubresourcesFluentImpl.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new CustomResourceSubresourceStatusBuilder().build());
  }
  public CustomResourceSubresourcesFluentImpl.StatusNested<A> editOrNewStatusLike(CustomResourceSubresourceStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    CustomResourceSubresourcesFluentImpl that = (CustomResourceSubresourcesFluentImpl) o;
    if (!java.util.Objects.equals(scale, that.scale)) return false;

    if (!java.util.Objects.equals(status, that.status)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(scale,  status,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (scale != null) { sb.append("scale:"); sb.append(scale + ","); }
    if (status != null) { sb.append("status:"); sb.append(status + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class ScaleNestedImpl<N> extends CustomResourceSubresourceScaleFluentImpl<CustomResourceSubresourcesFluentImpl.ScaleNested<N>> implements CustomResourceSubresourcesFluentImpl.ScaleNested<N>,Nested<N>{
    ScaleNestedImpl(CustomResourceSubresourceScale item) {
      this.builder = new CustomResourceSubresourceScaleBuilder(this, item);
    }
    ScaleNestedImpl() {
      this.builder = new CustomResourceSubresourceScaleBuilder(this);
    }
    CustomResourceSubresourceScaleBuilder builder;
    public N and() {
      return (N) CustomResourceSubresourcesFluentImpl.this.withScale(builder.build());
    }
    public N endScale() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends CustomResourceSubresourceStatusFluentImpl<CustomResourceSubresourcesFluentImpl.StatusNested<N>> implements CustomResourceSubresourcesFluentImpl.StatusNested<N>,Nested<N>{
    StatusNestedImpl(CustomResourceSubresourceStatus item) {
      this.builder = new CustomResourceSubresourceStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new CustomResourceSubresourceStatusBuilder(this);
    }
    CustomResourceSubresourceStatusBuilder builder;
    public N and() {
      return (N) CustomResourceSubresourcesFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}
